| Title: | Design and Analysis of Experiments with R |
|---|---|
| Description: | Contains Data frames and functions used in the book "Design and Analysis of Experiments with R", Lawson(2015) ISBN-13:978-1-4398-6813-3. |
| Authors: | John Lawson [aut, cre], Gerhard Krennrich [aut], Ruben Amoros [ctr] |
| Maintainer: | John Lawson <[email protected]> |
| License: | GPL-2 |
| Version: | 1.2-11 |
| Built: | 2026-05-27 09:33:46 UTC |
| Source: | https://github.com/cran/daewr |
This package contains the data sets and functions from the book Design and Analysis of Experiments with R published by CRC in 2013.
John Lawson
Maintainer: John Lawson <[email protected]>
J. Lawson, Design and Analysis of Experiments with R, CRC 2013.
Recalls Jones and Montgomery's 16 run screening designs from data frames
Altscreen(nfac, randomize=FALSE)Altscreen(nfac, randomize=FALSE)
nfac |
input- an integer |
randomize |
input - logical |
a data frame containing the alternate screening design
John Lawson
Jones, B. and Montgomery, D. C. (2010) "Alternatives to resolution IV screening designs in 16 runs", Int. J. Experimental Design and Process Optimization, Vol 1, No. 4, 2010.
Data from the Two-period crossover study of an antifungal agent in chapter 9 of Design and Analysis of Experiments with R
data(antifungal)data(antifungal)
A data frame with 34 observations on the following 5 variables.
Groupa factor with levels 1 2
Subjecta factor with levels 1 2 3 4 5 6 7 8 9 10 11 12 14 15 16 17 18
Perioda factor with levels 1 2
Treata factor with levels A B
pla numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(antifungal)data(antifungal)
Data from the apolipoprotein survey variance component study of Chapter 5 in Design and Analysis of Experiments with R
data(Apo)data(Apo)
A data frame with 30 observations on the following 2 variables.
laba factor with levels A B C D
conca numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Apo)data(Apo)
Data from the confounded apple slice browning experiment in chapter 7 of Design and Analysis of Experiments with R
data(apple)data(apple)
A data frame with 24 observations on the following 4 variables.
Blocka factor with levels 1 2 3 4
Aa factor with levels 0 1 2 3
Ba factor with levels 0 1 2
ratinga numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(apple)data(apple)
arsenic removal experimentData from the arsenic removal experiment in chapter 6 of Design and Analysis
of Experiments with R
data(arso)data(arso)
A data frame with 8 observations on the following 8 variables.
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
Ea factor with levels -1 1
Fa factor with levels -1 1
Ga factor with levels -1 1
y1a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(arso)data(arso)
arsenic removal experiment augmented with mirror imageData from the arsenic removal experiment augmented with mirror image in chapter 6 of Design and Analysis
of Experiments with R
data(augm)data(augm)
A data frame with 8 observations on the following 8 variables.
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
folda factor with levels original mirror
Da factor with levels -1 1
Ea factor with levels -1 1
Fa factor with levels -1 1
Ga factor with levels -1 1
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(augm)data(augm)
Data from the Confounded Block Dishwashing Experiment in chapter 7 of Design and Analysis of Experiments with R
data(Bdish)data(Bdish)
A data frame with 16 observations on the following 5 variables.
Blocksa factor with levels 1 2 3 4
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
ya numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Bdish)data(Bdish)
Data from the Confounded block fractional factorial mouse growth experiment in chapter 7 of Design and Analysis of Experiments with R
data(Bff)data(Bff)
A data frame with 16 observations on the following 5 variables.
Blocksa factor with levels 1 2 3 4 5 6 7 8
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
Ea factor with levels -1 1
Fa factor with levels -1 1
Ga factor with levels -1 1
Ha factor with levels -1 1
weighta numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Bff)data(Bff)
Data from the mouse liver enzyme experiment in chapter 4 of Design and Analysis of Experiments with R
data(bha)data(bha)
A data frame with 16 observations on the following 4 variables.
blocka factor with levels 1 2
straina factor with levels A/J 129O1a NIH BALB/c
treata factor with levels treated control
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(bha)data(bha)
This function computes the number of blocks, treatment frequency and lambda for a potential BIB design
BIBsize(t,k)BIBsize(t,k)
t |
input - number of levels of the treatment factor |
k |
input - blocksize or number of experimental units per block |
a list containing the b=number of blocks, r=number of treatment replicates and lambda for a potential BIB design with t levels of treatment factor and blocksize k.
John Lawson
Data from the extra-period crossover bioequivalence study in chapter 9 of Design and Analysis of Experiments with R
data(bioequiv)data(bioequiv)
A data frame with 108 observations on the following 5 variables.
Groupa factor with levels 1 2
Subjecta factor with levels 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 21 23 24 25 26 27 28 30 31 32 33 34 35 36 120 122 129
Perioda factor with levels 1 2 3
Treata factor with levels A B
Carrya factor with levels none A B
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(bioequiv)data(bioequiv)
Data from the Latin Square bioequivalence experiment in chapter 4 of Design and Analysis of Experiments with R
data(bioeqv)data(bioeqv)
A data frame with 9 observations on the following 4 variables.
Perioda factor with levels 1 2 3
Subjecta factor with levels 1 2 3
Treata factor with levels A B C
AUCa numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(bioeqv)data(bioeqv)
Data from the Variance component study of calcium in blood serum in chapter 5 of Design and Analysis of Experiments with R
data(blood)data(blood)
A data frame with 27 observations on the following 3 variables.
sola factor with levels 1 2 3 4
laba factor with levels A B C
calciuma numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(blood)data(blood)
from Chapter 3Data from Box and Meyer's unreplicated in chapter 3 of Design and Analysis
of Experiments with R
data(BoxM)data(BoxM)
A data frame with 16 observations on the following 4 variables.
Aa numeric vector containing the coded (-1,1) levels of factor A
Ba numeric vector containing the coded (-1,1) levels of factor B
Ca numeric vector containing the coded (-1,1) levels of factor C
Da numeric vector containing the coded (-1,1) levels of factor D
ya numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
Box, G. E. P. "George's Column", Quality Engineering, Vol. 3, pp. 405-410.
data(BoxM)data(BoxM)
Data from the blood pressure monitor experiment experiment in Chapter 7 of Design and Analysis of Experiments with R
data(BPmonitor)data(BPmonitor)
A data frame with 12 observations on the following 3 variables.
Blocka factor with levels 1 2 3 4 5 6
Treatmenta factor with levels "P" "A" "B" "C"
pressurea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(BPmonitor)data(BPmonitor)
Data from the bread rise experiment in chapter 2 of Design and Analysis of Experiments with R
data(bread)data(bread)
A data frame with 12 observations on the following 3 variables.
loafa numeric vector
timea numeric vector
heighta numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(bread)data(bread)
Data from the Split-Plot response surface for cake baking experiment in chapter 10 of Design and Analysis of Experiments with R
data(cakeb)data(cakeb)
A data frame with 11 observations on the following 6 variables.
Ovenruna factor with levels 1 2 3 4
x1a numeric vector
x2a numeric vector
ya numeric vector
x1sqa numeric vector
x2sqa numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(cakeb)data(cakeb)
Data from the CCD design for cement workability experiment in chapter 10 of Design and Analysis of Experiments with R
data(cement)data(cement)
A data frame with 20 observations on the following 4 variables.
Blocka factor with levels 1 2
x1a numeric vector
x2a numeric vector
x3a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(cement)data(cement)
Data from the Chemical process experiment in chapter 3 of Design and Analysis of Experiments with R
data(chem)data(chem)
A data frame with 16 observations on the following 4 variables.
Aa numeric vector containing the coded (-1,1) levels of factor A
Ba numeric vector containing the coded (-1,1) levels of factor B
Ca numeric vector containing the coded (-1,1) levels of factor C
Da numeric vector containing the coded (-1,1) levels of factor D
ya numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(chem)data(chem)
Data from the Williams' crossover design for sprinting experiment in chapter 9 of Design and Analysis of Experiments with R
data(chipman)data(chipman)
A data frame with 36 observations on the following 5 variables.
Squarea factor with levels 1 2
Groupa factor with levels 1 2 3
Subjecta factor with levels 1 2 3 4 5 6 7 8 9 10 11 12
Perioda factor with levels 1 2 3
Treata factor with levels 1 2 3
Carrya factor with levels 0 1 2 3
Timea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(chipman)data(chipman)
Data from the CO emissions experiment in chapter 3 of Design and Analysis of Experiments with R
data(COdata)data(COdata)
A data frame with 18 observations on the following 3 variables.
Etha factor with levels 0.1 0.2 0.3
Ratioa factor with levels 14 15 16
COa numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(COdata)data(COdata)
This function makes a colormap of the correlations of a design matrix stored in the data frame design
colormap(design, mod)colormap(design, mod)
design |
input - a data frame containing columns of the numeric factor levels |
mod |
input - a number indicationg the model for the colormap 1 = linear model containing only the terms in the dataframe 2 = linear model plus two factor interactions 3 = linear model plus 2 and 3 factor interactions 4 = linear model plus 2, 3, and 4 factor interactions |
John Lawson
## The function is currently defined as function(design,mod) { ##################### Inputs ########################################### # design - a data frame containing columns of the numeric factor levels # mod - the model for the color plot of correlations # 1 = Linear model containing only the terms in the data frame # 2 = Linear model plus two factor interactions # 3 = Linear model plus 2 and 3 factor interactions # 4 = Linear model plus 2, 3 and 4 factor interactions ######################################################################## y<-runif(nrow(design),0,1) if(mod==1) {test <- model.matrix(lm(y~(.),data=design))} if(mod==2) {test <- model.matrix(lm(y~(.)^2,data=design))} if(mod==3) {test <- model.matrix(lm(y~(.)^3,data=design))} if(mod==4) {test <- model.matrix(lm(y~(.)^4,data=design))} names<-colnames(test) names<-gsub(':','',names) names<-gsub('1','',names) colnames(test)<-names cmas<-abs(cor(test[,ncol(test):2])) cmas<-cmas[c((ncol(cmas)):1), ] rgb.palette <- colorRampPalette(c("white", "black"), space = "rgb") levelplot(cmas, main="Map of absolute correlations", xlab="", ylab="", col.regions=rgb.palette(120), cuts=100, at=seq(0,1,0.01),scales=list(x=list(rot=90))) }## The function is currently defined as function(design,mod) { ##################### Inputs ########################################### # design - a data frame containing columns of the numeric factor levels # mod - the model for the color plot of correlations # 1 = Linear model containing only the terms in the data frame # 2 = Linear model plus two factor interactions # 3 = Linear model plus 2 and 3 factor interactions # 4 = Linear model plus 2, 3 and 4 factor interactions ######################################################################## y<-runif(nrow(design),0,1) if(mod==1) {test <- model.matrix(lm(y~(.),data=design))} if(mod==2) {test <- model.matrix(lm(y~(.)^2,data=design))} if(mod==3) {test <- model.matrix(lm(y~(.)^3,data=design))} if(mod==4) {test <- model.matrix(lm(y~(.)^4,data=design))} names<-colnames(test) names<-gsub(':','',names) names<-gsub('1','',names) colnames(test)<-names cmas<-abs(cor(test[,ncol(test):2])) cmas<-cmas[c((ncol(cmas)):1), ] rgb.palette <- colorRampPalette(c("white", "black"), space = "rgb") levelplot(cmas, main="Map of absolute correlations", xlab="", ylab="", col.regions=rgb.palette(120), cuts=100, at=seq(0,1,0.01),scales=list(x=list(rot=90))) }
Data from the Single Array Experiment with an Elastometric Connector in Chapter 12 of Design and Analysis of Experiments with R. The control and noise factors are in coded levels.
data(connector)data(connector)
A data frame with 32 observations on the following 8 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(connector)data(connector)
Data from the control factor array and summary statistics for controller circuit design experiment in chapter 12 of Design and Analysis of Experiments with R
data(cont)data(cont)
A data frame with 18 observations on the following 6 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Fa numeric vector
lns2a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(cont)data(cont)
Data from the Split-plot response surface for ceramic pipe experiment in chapter 10 of Design and Analysis of Experiments with R
data(cpipe)data(cpipe)
A data frame with 48 observations on the following 6 variables.
WPa factor with levels 1 2 3 4 5 6 7 8 9 10 11 12
Aa numeric vector
Ba numeric vector
Pa numeric vector
Qa numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(cpipe)data(cpipe)
Data from the paecilomyces variotii culture experiment experiment in chapter 6 of Design and Analysis of Experiments with R
data(culture)data(culture)
A data frame with 16 observations on the following 9 variables.
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
Ea factor with levels -1 1
Fa factor with levels -1 1
Ga factor with levels -1 1
Ha factor with levels -1 1
y1a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(culture)data(culture)
Data from the Repeated measures study with dairy cow diets in chapter 9 of Design and Analysis of Experiments with R (compact format)
data(dairy)data(dairy)
A data frame with 120 observations on the following 5 variables.
Dieta factor with levels "Barley" "Mixed" "Lupins"
pr1a numeric vector
pr2a numeric vector
pr3a numeric vector
pr4a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(dairy)data(dairy)
Recalls Jones and Nachtsheim's Definitive screening designs for 3-level factors and 3-level factors with added 2-level categorical factors.
DefScreen(m, c=0, center=0, randomize=FALSE)DefScreen(m, c=0, center=0, randomize=FALSE)
m |
input- an integer, the m=number of 3-level factors |
c |
input- an integer, the m=number of 2-level categorical factors, default is zero if not supplied |
center |
input- an integer, the number of extra center points. This must be zero when c>0 |
randomize |
input - logical |
a data frame containing the definitive screening design with 3-level factors first followed by 2-level factors.
John Lawson
Jones, B. and Nachtsheim, C. J. (2011) "A Class of Three Level Designs for Definitive Screening in the Presence of Second-Order Effects", Journal of Quality Technology, Vol 43, No. 1, 2011, pp 1-15. Jones, B. and Nachtsheim, C. J. (2013) "Definitive Screening Designs with Added Two-Level Categorical Factors", Journal of Quality Technology, Vol 44, No. 2, 2013, pp. 121-129.
Data from rat behavior experiment in Chapter 4 of Design and Analysis of Experiments with R
data(drug)data(drug)
A data frame with 50 observations on the following 3 variables.
rata factor with levels 1 2 3 4 5 6 7 8 9 10
dosea factor with levels 0.0 0.5 1.0 1.5 2.0
ratea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(drug)data(drug)
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 1 whole plot factor and 1 sub-plot factor from a catalog
EEw1s1(des, randomize=FALSE)EEw1s1(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 1 whole plot factor and 2 sub-plot factors from a catalog
EEw1s2(des, randomize=FALSE)EEw1s2(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 1 whole plot factor and 3 sub-plot factors from a catalog
EEw1s3(des, randomize=FALSE)EEw1s3(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 2 whole plot factors and 1 sub-plot factor from a catalog
EEw2s1(des, randomize=FALSE)EEw2s1(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 2 whole plot factors and 1 sub-plot factor from a catalog
EEw2s2(des, randomize=FALSE)EEw2s2(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 2 whole plot factors and 1 sub-plot factor from a catalog
EEw2s3(des, randomize=FALSE)EEw2s3(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Recalls Jones and Goos JQT Estimation Equivalent Response Surface Designs for 3 whole plot factors and 1-2 sub-plot factors from a catalog
EEw3(des, randomize=FALSE)EEw3(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Jones, B. and Goos, P.(2012) "An Algorithm for Finding D-Efficient Equivalent-Estimation Second-Order Split Plot Designs", Journal of Quality Technology, Vol 44, No. 4, pp281-303, 2012.
Data from the single array and raw response for silicon layer growth experiment in chapter 12 of Design and Analysis of Experiments with R
data(eptaxr)data(eptaxr)
A data frame with 64 observations on the following 9 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
Ha numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(eptaxr)data(eptaxr)
Data from the control array and variance of response for silicon layer growth experiment in chapter 12 of Design and Analysis of Experiments with R
data(eptaxs2)data(eptaxs2)
A data frame with 16 observations on the following 9 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
Ha numeric vector
s2a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(eptaxs2)data(eptaxs2)
Data from the control array and mean response for silicon layer growth experiment in chapter 12 of Design and Analysis of Experiments with R
data(eptaxyb)data(eptaxyb)
A data frame with 16 observations on the following 9 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
Ha numeric vector
ybara numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(eptaxyb)data(eptaxyb)
Gets F-distribution critical values
Fcrit(alpha, nu1, nu2)Fcrit(alpha, nu1, nu2)
alpha |
input- right tail area beyond critical value |
nu1 |
input - numerator degrees of freedom for F-distribution |
nu2 |
input - denominator degrees of freedom for F-distribution |
returned critical value
John Lawson
This function performs a single step of a hierarchical forward stepwise regression by entering additional term(s) to a model already created by ihstep or fhstep. If an interaction or quadratic term is entered first, the parent main effects are also entered into the model. This function is called by HierAFS.R
fhstep(y,des,m,c,prvm)fhstep(y,des,m,c,prvm)
y |
input - this is a data frame containing a single numeric column of response data. |
des |
input - this is a data frame containing the numeric columns of the candidate independent variables. The column names of des are of length 1 i.e., letters of the alphabet. The m three-level factors always preceed the c two-level factors in the design. |
m |
input - this is an integer equal to the number of three-level factors in the design |
c |
input - this is an integer equal to the number of two-level factors in the design. Note m+c must be equal to the number of columns of des. |
prvm |
input - this is a vector of text names of the terms in the model. This is created as the value resulting from running ihstep or fhstep. |
returned vector of terms entered in the model at this step.
John Lawson
This function performs a single step of a forward stepwise regression by entering an additional 2nd order term to a model already created by FitDefSc.R or fhstepDS.R This function is called by FitDefSc.R
fhstepDS(y,des,m,c,prvm)fhstepDS(y,des,m,c,prvm)
y |
input - this is a data frame containing a single numeric column of response data. |
des |
input - this is a data frame containing the numeric columns of the candidate independent variables. The column names of des are of length 1 i.e., letters of the alphabet. The m three-level factors always preceed the c two-level factors in the design. |
m |
input - this is an integer equal to the number of three-level factors in the design |
c |
input - this is an integer equal to the number of two-level factors in the design. Note m+c must be equal to the number of columns of des. |
prvm |
input - this is a vector of text names of the terms in the model. This is created as the value resulting from running ihstep or fhstep. |
returned vector of terms entered in the model at this step.
John Lawson
This function finds the first term to enter a hierarchical forward stepwise regression. If the term is an interaction or quadratic term, the parent main effects are also included. This function is called by ihstep.R
firstm(y,des)firstm(y,des)
y |
input - this is a data frame containing a single numeric column of response data. |
des |
input - this is a data frame containing the numeric columns of the candidate independent variables. The column names of des are of length 1. The m three-level factors always preceed the c two-level factors in the design. |
returned vector of terms to be entered in the model at the first step.
John Lawson
This function performs fits a model to a Definitive Screeing Design by first restricting main effects to the smallest main effects and those significant at at least the .20 level in a main effects model. Next forward stepwise selection is used to enter 2 factor interactions and quadratic effects.
FitDefSc(y,design,alpha=.05)FitDefSc(y,design,alpha=.05)
y |
input - this is a vector containing a single numeric column of response data. |
design |
input - this is a data frame containing the numeric columns of the candidate independent variables created by the DefScreen function with only numerical factors i.e. c=0. The factor names or colnames(design) should always be of length 1 (for example letters of the alphabet "A", "B", etc.) |
alpha |
input - alpha to enter in the forward stepwise regression with second order candidates should be between 0.05 and 0.20 |
John Lawson
This function finds the first term to enter a hierarchical forward stepwise regression. If the term is an interaction or quadratic term, the parent main effects are also included. This function is called by ihstep.R
fnextrm(y,des,prvm)fnextrm(y,des,prvm)
y |
input - this is a data frame containing a single numeric column of response data. |
des |
input - this is a data frame containing the numeric columns of the candidate independent variables. The column names of des are of length 1. The m three-level factors always preceed the c two-level factors in the design. |
prvm |
input - this is a vector of text names of the terms in the model. This is created as the value resulting from running ihstep or fhstep. |
returned vector of terms to be entered in the model at the next step.
John Lawson
This function finds the first term to enter a hierarchical forward stepwise regression. If the term is an interaction or quadratic term, the parent main effects are also included. This function is called by ihstep.R
fntrmDS(y,des,prvm)fntrmDS(y,des,prvm)
y |
input - this is a data frame containing a single numeric column of response data. |
des |
input - this is a data frame containing the numeric columns of the candidate independent variables. The column names of des are of length 1. The m three-level factors always preceed the c two-level factors in the design. |
prvm |
input - this is a vector of text names of the terms in the model. This is created as the value resulting from running ihstep or fhstep. |
returned vector of terms to be entered in the model at the next step.
John Lawson
Calculates the power for the non-central F-distribution
Fpower(alpha, nu1, nu2, nc)Fpower(alpha, nu1, nu2, nc)
alpha |
input - critical value alpha |
nu1 |
input - degrees of freedom for numerator |
nu2 |
input - degrees of freedom for denominator |
nc |
input - noncentrality parameter |
probability of exceeding fcrit(alpha, nu1,nu2) with the non-central F-distribution with nu1 and nu2 degrees of freedom and noncentrality parameter nc
John Lawson
Calculates the power for one-way ANOVA
Fpower1(alpha,nlev,nreps,Delta,sigma)Fpower1(alpha,nlev,nreps,Delta,sigma)
alpha |
input - significance level of the F-test. |
nlev |
input - the number of levels of the factor |
nreps |
input - the number of replicates in each level of the factor. |
Delta |
input - the size of a practical difference in two cell means. |
sigma |
input - the standard deviation of the experimental error. |
probability of exceeding fcrit(alpha, nu1,nu2) with the non-central F-distribution with nu1 and nu2 degrees of freedom and noncentrality parameter nc
John Lawson
Calculates the power for a two-way ANOVA
Fpower2(alpha,nlev,nreps,Delta,sigma)Fpower2(alpha,nlev,nreps,Delta,sigma)
alpha |
input - significance level of the F-test. |
nlev |
input - vector of length two containing the number of levels of the factors. |
nreps |
input - the the number of replicates in each combination of factor levels. |
Delta |
input - the size of a practical difference in two marginal factor level means. |
sigma |
input - the standard deviation of the experimental error. |
probability of exceeding fcrit(alpha, nu1,nu2) with the non-central F-distribution with nu1 and nu2 degrees of freedom and noncentrality parameter nc
John Lawson
This function makes a full normal plot of the elements of the vector called effects
fullnormal(effects, labs, alpha = 0.05, refline = "TRUE")fullnormal(effects, labs, alpha = 0.05, refline = "TRUE")
effects |
input - vector of effects to be plotted |
labs |
input - vector of labels of the effects to be plotted |
alpha |
input - alpha level for labeling of significant effects using Lenth statistic |
refline |
input - logical variable that indicates whether a reference line is added to the plot (default is "TRUE") |
John Lawson
Data from the Gauge R&R Study in chapter 5 of Design and Analysis of Experiments with R
data(gagerr)data(gagerr)
A data frame with 60 observations on the following 3 variables.
parta factor with levels 1 2 3 4 5 6 7 8 9 10
opera factor with levels 1 2 3
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(gagerr)data(gagerr)
This function computes the gap statistic which is used to test for an outlier using Daniels method
gapstat(beta, pse)gapstat(beta, pse)
beta |
input - vector of coefficients from saturated model fit to the data |
pse |
input - Lenth's PSE statistic calculated from the elements of beta |
returned gap statistic
John Lawson
design.
This function uses Daniel's Method to find an outlier in an unreplicated design.
Gaptest(DesY)Gaptest(DesY)
DesY |
input this is a data frame containing an unreplicated |
John Lawson
Box, G.E.P. (1991) "George's column: Finding bad values in factorial designs", Quality Engineering, 3, 249-254.
Data from the unreplicated split-plot fractional-factorial experiment on geometric distortion of drive gears in chapter 8 of Design and Analysis of Experiments with R
data(gear)data(gear)
A data frame with 16 observations on the following 6 variables.
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Pa factor with levels -1 1
Qa factor with levels -1 1
ya numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(gear)data(gear)
This function makes a half normal plot of the elements of the vector called effects
halfnorm(effects, labs, alpha = 0.05, refline = "TRUE")halfnorm(effects, labs, alpha = 0.05, refline = "TRUE")
effects |
input - vector of effects to be plotted |
labs |
input - vector of labels of the effects to be plotted |
alpha |
input - alpha level for labeling of significant effects using Lenth statistic |
refline |
input - logical variable that indicates whether a reference line is added to the plot (default is "TRUE") |
John Lawson
Data from the low grade hardwood conjoint study in chapter 6 of Design and Analysis of Experiments with R
data(hardwood)data(hardwood)
A data frame with 12 observations on the following 5 variables.
Designa factor with levels "RC" "AC" "OCI" "OCII"
Pricea numeric variable
Densitya factor with levels "Clear" "Heavy" "Medium"
Guaranteea factor with levels "1y" "Un"
Ratinga numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(hardwood)data(hardwood)
This function performs a hierarchical forward stepwise regression. If an interaction or quadratic term is entered in the model, the parent main effects are also entered into the model.
HierAFS(y,x,m,c,step)HierAFS(y,x,m,c,step)
y |
input - this is a vector containing a single numeric column of response data. |
x |
input - this is a data frame containing the numeric columns of the candidate independent variables. The m three-level factors always preceed the c two-level factors in the design. The factor names or colnames(x) should always be of length (for example letters of the alphabet "A", "B", etc.) |
m |
input - this is an integer equal to the number of three-level factors in the design |
c |
input - this is an integer equal to the number of two-level factors in the design. Note m+c must be equal to the number of columns of des. |
step |
input - this is a single numeric value containing the n umber of steps requested. |
returned data frame the first column is a factor variable containing the formula for the model fit at each step, the second numeric column is the R-square statistic for the model fit with each formula.
Gerhard Krennrich, and modified by John Lawson
This function performs the first step of a hierarchical forward stepwise regression. If an interaction or quadratic term is entered first, the parent main effects are also entered into the model. This function is called by HierAFS.R
ihstep(y,des,m,c)ihstep(y,des,m,c)
y |
input - this is a data frame containing a single numeric column of response data. |
des |
input - this is a data frame containing the numeric columns of the candidate independent variables. The column names of des are of length 1 i.e., letters of the alphabet. The m three-level factors always preceed the c two-level factors in the design. |
m |
input - this is an integer equal to the number of three level factors in the design |
c |
input - this is an integer equal to the number of two level factors in the design. Note m+c must be equal to the number of columns of des. |
returned vector of terms entered in the model at this step.
John Lawson
Data from the single array for injection molding experiment in chapter 12 of Design and Analysis of Experiments with R
data(inject)data(inject)
A data frame with 20 observations on the following 8 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
shrinkagea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(inject)data(inject)
interleaves two vectors
interleave(v1,v2)interleave(v1,v2)
v1 |
input - first vector |
v2 |
input - second vector |
vector
Plot of the factor effects with significance levels based on robust estimation of contrast standard errors.
LenthPlot(obj, alpha = 0.05, plt = TRUE, limits = TRUE, xlab = "factors", ylab = "effects", faclab = NULL, cex.fac = graphics::par("cex.lab"), cex.axis=graphics::par("cex.axis"), adj = 1, ...)LenthPlot(obj, alpha = 0.05, plt = TRUE, limits = TRUE, xlab = "factors", ylab = "effects", faclab = NULL, cex.fac = graphics::par("cex.lab"), cex.axis=graphics::par("cex.axis"), adj = 1, ...)
obj |
object of class |
alpha |
numeric. Significance level used for the margin of error (ME) and simultaneous margin of error (SME). See Lenth(1989). |
plt |
logical. If |
limits |
logical. If |
xlab |
character string. Used to label the x-axis. "factors" as default. |
ylab |
character string. Used to label the y-axis. "effects" as default. |
faclab |
list with components |
cex.fac |
numeric. Character size used for the factor labels. |
cex.axis |
numeric. Character size used for the axis. |
adj |
numeric between 0 and 1. Determines where to place the
"ME" (margin of error) and the "SME" (simultaneous margin of error) labels
(character size of 0.9* |
... |
extra parameters passed to |
If obj is of class lm, 2*coef(obj) is used as factor
effect with the intercept term removed. Otherwise, obj should be a
vector with the factor effects. Robust estimate of the contrasts standard
error is used to calculate marginal (ME) and simultaneous margin
of error (SME) for the provided significance (1 - alpha) level.
See Lenth(1989). Spikes are used to display the factor effects.
If faclab is NULL, factors are labelled with the effects or
coefficient names. Otherwise, those faclab\$idx factors are labelled
as faclab\$lab. The rest of the factors are blanked.
The function is called mainly for its side effect. It returns a vector with the value of alpha used, the estimated PSE, ME and SME.
Ernesto Barrios. Extension provided by Kjetil Kjernsmo (2013).
Lenth, R. V. (1989). "Quick and Easy Analysis of Unreplicated Factorials". Technometrics Vol. 31, No. 4. pp. 469–473.
This function uses the LGB Method to detect significant effects in unreplicated fractional factorials.
LGB(Beta, alpha = 0.05, rpt = TRUE, plt = TRUE, pltl = TRUE)LGB(Beta, alpha = 0.05, rpt = TRUE, plt = TRUE, pltl = TRUE)
Beta |
input - this is the numeric vector of effects or coefficients to be tested |
alpha |
input - This is the significance level of the test |
rpt |
input - this is a logical variable that controls whether the report is written (default is TRUE) |
plt |
input - this is a logical variable that controls whether a half-normal plot is made (default is TRUE) |
pltl |
input - this is a logical variable that controls whether the significance limit line is drawn on the half-normal plot (default is TRUE) |
John Lawson
Lawson, J., Grimshaw, S., Burt, J. (1998) "A quantitative method for identifying active contrasts in unreplicated factorial experiments based on the half-normal plot", Computational Statistics and Data Analysis, 26, 425-436.
This function uses the LGB Method to detect significant effects in unreplicated fractional factorials.
LGBc(Beta, alpha = 0.05, rpt = TRUE, plt = TRUE, pltl = TRUE)LGBc(Beta, alpha = 0.05, rpt = TRUE, plt = TRUE, pltl = TRUE)
Beta |
input - this is the numeric vector of effects or coefficients to be tested |
alpha |
input - This is the significance level of the test |
rpt |
input - this is a logical variable that controls whether the report is written (default is TRUE) |
plt |
input - this is a logical variable that controls whether a half-normal plot is made (default is TRUE) |
pltl |
input - this is a logical variable that controls whether the significance limit line is drawn on the half-normal plot (default is TRUE) |
John Lawson
Lawson, J., Grimshaw, S., Burt, J. (1998) "A quantitative method for identifying active contrasts in unreplicated factorial experiments based on the half-normal plot", Computational Statistics and Data Analysis, 26, 425-436.
Gets mod of a to base b
mod(a,b)mod(a,b)
a |
input- an integer |
b |
input - an integer |
remainder of a/b or mod(a,b)
John Lawson
Recalls Li and Nachtsheim's model robust factorial designs from a catalog of data frames
ModelRobust(des, randomize=FALSE)ModelRobust(des, randomize=FALSE)
des |
input- a character variable containing the name of a design in the catalog. If left blank, the function prints a table showing all the design names in the catalog |
randomize |
input- a logical |
design
John Lawson
Li, W. and Nachtsheim, C. J. (2000) "Model Robust factorial Designs", Technometrics, Vol 42, No. 4, pp345-352, 2000.
Data from the mixture process variable experiment with mayonnaise in chapter 11 of Design and Analysis of Experiments with R
data(MPV)data(MPV)
A data frame with 35 observations on the following 4 variables.
x1a numeric vector
x2a numeric vector
x3a numeric vector
z1a numeric vector
z2a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(MPV)data(MPV)
Data from the Yields of naphthalene black of Chapter 5 in Design and Analysis of Experiments with R
data(Naph)data(Naph)
A data frame with 30 observations on the following 2 variables.
samplea factor with levels 1 2 3 4 5 6
yielda numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Naph)data(Naph)
Selects the columns from a Plackett-Burman Design Produced by FrF2 that will minimize model dependence for main effects and two factor interactions and returns the design in a data frame
OptPB(nruns, nfactors, randomize=FALSE)OptPB(nruns, nfactors, randomize=FALSE)
nruns |
input- an integer representing the number of runs in the design |
nfactors |
input - in integer representing the number of factors in the design |
randomize |
input - logical |
design
John Lawson
Fairchild, K. (2011) "Screening Designs that Minimize Model Dependence", MS Project Department of Statistics Brigham Young University, Dec. 2011.
Data from the Blocked response surface design for pastry dough experiment in chapter 10 of Design and Analysis of Experiments with R
data(pastry)data(pastry)
A data frame with 28 observations on the following 5 variables.
Blocka factor with levels 1 2 3 4 5 6 7
x1a numeric vector
x2a numeric vector
x3a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(pastry)data(pastry)
Creates a 12, 20, or 24 run Plackett-Burman design in a data frame with numeric factor levels by cyclically rotating the factor leves in the first row
PBDes(nruns, nfactors, randomize=FALSE)PBDes(nruns, nfactors, randomize=FALSE)
nruns |
input- an integer representing the number of runs in the design |
nfactors |
input - in integer representing the number of factors in the design |
randomize |
input - logical |
design
John Lawson
Lawson, J. (2015) "Design and Analysis of Experiments with R page 229",CRC Press, Boca Raton, 2015.
Data from the Pesticide formulation experiment in chapter 11 of Design and Analysis of Experiments with R
data(pest)data(pest)
A data frame with 13 observations on the following 4 variables.
x1a numeric vector
x2a numeric vector
x3a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(pest)data(pest)
Data from the pesticide application experiment in chapter 5 of Design and Analysis of Experiments with R
data(pesticide)data(pesticide)
A data frame with 16 observations on the following 4 variables.
forma factor with levels A B
techa factor with levels 1 2
plota factor with levels 1 2
residuea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(pesticide)data(pesticide)
experiment on plasma treatment of paperData from the unreplicated split-plot experiment on plasma treatment of paper in chapter 8 of Design and Analysis
of Experiments with R
data(plasma)data(plasma)
A data frame with 32 observations on the following 6 variables.
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
Ea factor with levels -1 1
ya numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(plasma)data(plasma)
Data from the Polvoron mixture experiment in chapter 11 of Design and Analysis of Experiments with R
data(polvdat)data(polvdat)
A data frame with 12 observations on the following 4 variables.
x1a numeric vector
x2a numeric vector
x3a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(polvdat)data(polvdat)
Data from the polymerization strength variability study in chapter 5 of Design and Analysis of Experiments with R
data(polymer)data(polymer)
A data frame with 120 observations on the following 5 variables.
lota factor with levels 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
boxa factor with levels 1 2
prepa factor with levels 1 2
testa factor with levels 1 2
strengtha numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(polymer)data(polymer)
Data from the complete control factor array and noise factor array for connector experiment in chapter 12 of Design and Analysis of Experiments with R
data(prodstd)data(prodstd)
A data frame with 16 observations on the following 16 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
Pofa numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(prodstd)data(prodstd)
Data from the Library of substituted hydroxyphenylurea compounds in chapter 10 of Design and Analysis of Experiments with R (compact format)
data(qsar)data(qsar)
A data frame with 36 observations on the following 4 variables.
Compounda numeric vector
HEa numeric vector
DMza numeric vector
S0Ka numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(qsar)data(qsar)
Data from the cattle rations design experiment in chapter 10 of Design and Analysis of Experiments with R
data(Rations)data(Rations)
A data frame with 45 observations on the following 4 variables.
Blocka factor with levels 1 2 3 4 5 6 7 8
x1a numeric vector
x2a numeric vector
ADGa numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Rations)data(Rations)
Data from the generalized RCB golf driving experiment in chapter 4 of Design and Analysis of Experiments with R
data(rcb)data(rcb)
A data frame with 135 observations on the following 3 variables.
ida factor with levels 1 2 3 4 5 6 7 8 9
teehgta factor with levels 1 2 3
cdistancea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(rcb)data(rcb)
Data from the Herbicide degradation experiment in chapter 9 of Design and Analysis of Experiments with R
data(residue)data(residue)
A data frame with 16 observations on the following 3 variables.
soila factor with levels "C" "P"
moisturea factor with levels "L" "H"
tempa factor with levels 10 30
X1a numeric vector
X2a numeric vector
X3a numeric vector
X4a numeric vector
X5a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(residue)data(residue)
Data from the Rubber Elasticity Study in chapter 5 of Design and Analysis of Experiments with R
data(rubber)data(rubber)
A data frame with 96 observations on the following 4 variables.
suppliera factor with levels A B C D
batcha factor with levels I II III IV
samplea factor with levels 1 2
elasticitya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(rubber)data(rubber)
Data from the Split-plot experiment on sausage casing with RCB in whole plot in chapter 7 of Design and Analysis of Experiments with R
data(sausage)data(sausage)
A data frame with 32 observations on the following 5 variables.
Blocka factor with levels 1 2
Gbatcha factor with levels 1 2 3 4
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
ysa numeric vector containing the response
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(sausage)data(sausage)
Data from the single array for starting motor experiment in chapter 12 of Design and Analysis of Experiments with R
data(Smotor)data(Smotor)
A data frame with 18 observations on the following 6 variables.
Aa factor with levels 1 2
Ba factor with levels 1 2 3
Ca factor with levels 1 2 3
Da factor with levels 1 2 3
Ea factor with levels 1 2
torquea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Smotor)data(Smotor)
Data from the dry mix soup experiment in chapter 6 of Design and Analysis of Experiments with R
data(soup)data(soup)
A data frame with 16 observations on the following 6 variables.
Aa factor with levels -1 1
Ba factor with levels -1 1
Ca factor with levels -1 1
Da factor with levels -1 1
Ea factor with levels -1 1
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(soup)data(soup)
Data from the dry soup mix variance component study of Chapter 5 in Design and Analysis of Experiments with R
data(soupmx)data(soupmx)
A data frame with 12 observations on the following 2 variables.
batcha factor with levels 1 2 3 4
weighta numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(soupmx)data(soupmx)
Data from the Split-plot cookie baking experiment in chapter 8 of Design and Analysis of Experiments with R
data(splitPdes)data(splitPdes)
A data frame with 24 observations on the following 5 variables.
shorta factor with levels 100 80
trayTa factor with levels RoomT Hot
bakeTa factor with levels low mid high
batcha factor with levels 1 2
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(splitPdes)data(splitPdes)
Data from the Split-plot mixture process variable experiment with vinyl in chapter 10 of Design and Analysis of Experiments with R
data(SPMPV)data(SPMPV)
A data frame with 28 observations on the following 7 variables.
wpa factor with levels 1 2 3 4 5 6 7
z1a numeric vector
z2a numeric vector
x1a numeric vector
x2a numeric vector
x3a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(SPMPV)data(SPMPV)
Makes standard order
stdord(m)stdord(m)
m |
input - vector length |
vector in standard order
Data from the Repeated measures study with dairy cow diets in chapter 9 of Design and Analysis of Experiments with R (strung out format)
data(strung)data(strung)
A data frame with 120 observations on the following 5 variables.
Dieta factor with levels "Barley" "Mixed" "Lupins"
Cowa factor with levels 1 2 3 4 5 6 7 8 9 10
weeka factor with levels 1 2 3 4
proteina numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(strung)data(strung)
Data from the strung out control factor array and raw response data for Ina tile experiment in chapter 12 of Design and Analysis of Experiments with R
data(strungtile)data(strungtile)
A data frame with 16 observations on the following 16 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
Ha numeric vector
AHa numeric vector
BHa numeric vector
CHa numeric vector
DHa numeric vector
EHa numeric vector
FHa numeric vector
GHa numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(strungtile)data(strungtile)
Sugarbeet data from chapter 2 of Design and Analysis of Experiments with R
data(sugarbeet)data(sugarbeet)
A data frame with 18 observations on the following 2 variables.
treata factor with levels A B C D
yielda numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(sugarbeet)data(sugarbeet)
Data from the taste test panel experiment in Chapter 7 of Design and Analysis of Experiments with R
data(taste)data(taste)
A data frame with 24 observations on the following 3 variables.
panelista factor with levels 1 2 3 4 5 6 7 8 9 10 11 12
recipea factor with levels "A" "B" "C" "D"
scorea numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(taste)data(taste)
Data from the teaching experiment in chapter 2 of Design and Analysis of Experiments with R
data(teach)data(teach)
A data frame with 30 observations on the following 4 variables.
classa numeric vector
methoda factor with levels 1 2 3
scorea factor with levels 1 2 3 4 5
counta numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(teach)data(teach)
Data from the Tetracycline concentration in plasma study in chapter 10 of Design and Analysis of Experiments with R (compact format)
data(Tet)data(Tet)
A data frame with 9 observations on the following 2 variables.
Timea numeric vector
Conca numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Tet)data(Tet)
Data from the control factor array and summary statistics for Ina tile experiment in chapter 12 of Design and Analysis of Experiments with R
data(tile)data(tile)
A data frame with 8 observations on the following 11 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
y1a numeric vector
y2a numeric vector
ybara numeric vector
lns2a numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(tile)data(tile)
Data from the Box-Behnken design for trebuchet experiment in chapter 10 of Design and Analysis of Experiments with R
data(Treb)data(Treb)
A data frame with 15 observations on the following 4 variables.
x1a numeric vector
x2a numeric vector
x3a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(Treb)data(Treb)
This function performs Tukey's single degree of freedom test for interaction in an unreplicated two-factor design
Tukey1df(data)Tukey1df(data)
data |
input - this is a data frame with three variables, the first variable is a numeric response and next two variables are factors. There should be |
John Lawson
function for getting confidence intervals on variance components estimated by the method of moments
vci(confl,c1,ms1,nu1,c2,ms2,nu2)vci(confl,c1,ms1,nu1,c2,ms2,nu2)
confl |
input- confidence level |
c1 |
input - linear combination coefficient of ms1 in the estimated variance component |
ms1 |
input - Anova mean square 1 |
nu1 |
input - Anova degrees of freedom for mean square 1 |
c2 |
input - linear combination coefficient of ms2 in the estimated variance component |
ms2 |
input - Anova mean square 2 |
nu2 |
input - Anova degrees of freedom for mean square 2 |
returned delta, Lower and Upper limits
John Lawson
Data from vinyl plasticiser formulation experiment in chapter 11 of Design and Analysis of Experiments with R
data(vinyl)data(vinyl)
A data frame with 40 observations on the following 7 variables.
WPa numeric vector
x1a numeric vector
x2a numeric vector
x3a numeric vector
z1a numeric vector
z2a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(vinyl)data(vinyl)
Data from the Assay of Viral Contamination experiment in chapter 3 of Design and Analysis of Experiments with R
data(virus)data(virus)
A data frame with 18 observations on the following 3 variables.
ya numeric vector
Samplea factor with levels 1 2 3 4 5 6
Dilutiona factor with levels 3 4 5
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(virus)data(virus)
Data from the Volt meter experiment in chapter 3 of Design and Analysis of Experiments with R
data(volt)data(volt)
A data frame with 16 observations on the following 3 variables.
ya numeric vector
Aa factor containing the levels (22, 32) of factor A
Ba factor containing the levels (0.5, 5.0) of factor B
Ca factor containing the levels (0.5, 5.0) of factor C
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(volt)data(volt)
Data from the web page design experiment in chapter 3 of Design and Analysis of Experiments with R
data(web)data(web)
A data frame with 36 observations on the following 6 variables.
Aa factor with levels 1 2
Ba factor with levels 1 2
Ca factor with levels 1 2
Da factor with levels 1 2
visitorsa numeric vector
signupa numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(web)data(web)
Data from the Single Array Experiment in Exercise 5 of Chapter 12 in Design and Analysis of Experiments with R. The factors are in coded levels.
data(WeldS)data(WeldS)
A data frame with 16 observations on the following 16 variables.
Da numeric vector
Ha numeric vector
Ga numeric vector
Aa numeric vector
Fa numeric vector
GHa numeric vector
Ca numeric vector
Ba numeric vector
Ja numeric vector
Ea numeric vector
ACa numeric vector
AHa numeric vector
AGa numeric vector
e1a numeric vector
e2a numeric vector
ya numeric vector
Design and Analysis of Experiments with R, by John Lawson, CRC/Chapman Hall
data(WeldS)data(WeldS)